@@ -108,8 +108,8 @@ class SusFile():
                         True,
                         "get",
                         127,
-                        [SusField(thing.location, "ID of the entity to get", "id", SusType(thing.location, None, "Int", [8], []), None, None, None)],
-                        [SusField(thing.location, "Entity with that ID", "entity", SusType(thing.location, None, thing.name, [], []), None, None, None)],
+                        [SusField(thing.location, "ID of the entity to get", "id", SusType(thing.location, None, "Int", [8], []), None, None)],
+                        [SusField(thing.location, "Entity with that ID", "entity", SusType(thing.location, None, thing.name, [], []), None, None)],
                         ["invalid_id"],
                         [],
                         None
@@ -120,7 +120,7 @@ class SusFile():
                         False,
                         "update",
                         127,
-                        [SusField(thing.location, "The values to update", "entity", SusType(thing.location, None, thing.name, [], []), None, None, None)],
+                        [SusField(thing.location, "The values to update", "entity", SusType(thing.location, None, thing.name, [], []), None, None)],
                         [],
                         ["invalid_entity"],
                         [],
